/*
 * heap_stats.cpp
 *
 *  Created on: Nov 21, 2023
 *      Author: Dario
 */

#include <sta/rtos/debug/heap_stats.hpp>

#ifdef STA_DEBUGGING_ENABLED

#include <FreeRTOS.h>
#include <cmsis_os2.h>


namespace sta
{
	namespace rtos
	{
		size_t getAvailableHeapSpace()
		{
			xHeapStats stats;
			vPortGetHeapStats(&stats);

			return stats.xAvailableHeapSpaceInBytes;
		}

		size_t getNumAllocs()
		{
			xHeapStats stats;
			vPortGetHeapStats(&stats);

			return stats.xNumberOfSuccessfulAllocations;
		}

		size_t getNumFrees()
		{
			xHeapStats stats;
			vPortGetHeapStats(&stats);

			return stats.xNumberOfSuccessfulFrees;
		}

		void printHeapStats()
		{
			xHeapStats stats;
			vPortGetHeapStats(&stats);

			STA_DEBUG_PRINTF(
				"[HEAP STATS] \n  Available: %d\n  Lowest: %d\n  Mallocs: %d\n  Frees: %d",
				stats.xAvailableHeapSpaceInBytes,
				stats.xMinimumEverFreeBytesRemaining,
				stats.xNumberOfSuccessfulAllocations,
				stats.xNumberOfSuccessfulFrees
			);
		}
	} // namespace rtos
} // namespace sta

#endif // STA_DEBUGGING_ENABLED



